summaryrefslogtreecommitdiffstats
path: root/src/sources/labelsourcePrefs.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/sources/labelsourcePrefs.cpp')
-rw-r--r--src/sources/labelsourcePrefs.cpp92
1 files changed, 46 insertions, 46 deletions
diff --git a/src/sources/labelsourcePrefs.cpp b/src/sources/labelsourcePrefs.cpp
index fda5ea3..cd7eb47 100644
--- a/src/sources/labelsourcePrefs.cpp
+++ b/src/sources/labelsourcePrefs.cpp
@@ -11,72 +11,72 @@
#include "labelsourcePrefs.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qframe.h>
-#include <qlabel.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqframe.h>
+#include <tqlabel.h>
#include <kcolorbutton.h>
#include <kfontrequester.h>
-#include <qcombobox.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqcombobox.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
/*
* Constructs a LabelSourcePrefs as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-LabelSourcePrefs::LabelSourcePrefs( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+LabelSourcePrefs::LabelSourcePrefs( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "LabelSourcePrefs" );
- LabelSourcePrefsLayout = new QVBoxLayout( this, 0, 6, "LabelSourcePrefsLayout");
+ LabelSourcePrefsLayout = new TQVBoxLayout( this, 0, 6, "LabelSourcePrefsLayout");
- defaultSourcePrefsFrame = new QFrame( this, "defaultSourcePrefsFrame" );
- defaultSourcePrefsFrame->setFrameShape( QFrame::NoFrame );
- defaultSourcePrefsFrame->setFrameShadow( QFrame::Plain );
- defaultSourcePrefsFrameLayout = new QVBoxLayout( defaultSourcePrefsFrame, 0, 6, "defaultSourcePrefsFrameLayout");
+ defaultSourcePrefsFrame = new TQFrame( this, "defaultSourcePrefsFrame" );
+ defaultSourcePrefsFrame->setFrameShape( TQFrame::NoFrame );
+ defaultSourcePrefsFrame->setFrameShadow( TQFrame::Plain );
+ defaultSourcePrefsFrameLayout = new TQVBoxLayout( defaultSourcePrefsFrame, 0, 6, "defaultSourcePrefsFrameLayout");
- taskbartitleLabel = new QLabel( defaultSourcePrefsFrame, "taskbartitleLabel" );
- QFont taskbartitleLabel_font( taskbartitleLabel->font() );
+ taskbartitleLabel = new TQLabel( defaultSourcePrefsFrame, "taskbartitleLabel" );
+ TQFont taskbartitleLabel_font( taskbartitleLabel->font() );
taskbartitleLabel_font.setBold( TRUE );
taskbartitleLabel->setFont( taskbartitleLabel_font );
defaultSourcePrefsFrameLayout->addWidget( taskbartitleLabel );
- layout13 = new QHBoxLayout( 0, 0, 6, "layout13");
+ tqlayout13 = new TQHBoxLayout( 0, 0, 6, "tqlayout13");
- colorLabel = new QLabel( defaultSourcePrefsFrame, "colorLabel" );
- layout13->addWidget( colorLabel );
+ colorLabel = new TQLabel( defaultSourcePrefsFrame, "colorLabel" );
+ tqlayout13->addWidget( colorLabel );
colorButton = new KColorButton( defaultSourcePrefsFrame, "colorButton" );
- layout13->addWidget( colorButton );
- spacer1 = new QSpacerItem( 350, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
- layout13->addItem( spacer1 );
- defaultSourcePrefsFrameLayout->addLayout( layout13 );
+ tqlayout13->addWidget( colorButton );
+ spacer1 = new TQSpacerItem( 350, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
+ tqlayout13->addItem( spacer1 );
+ defaultSourcePrefsFrameLayout->addLayout( tqlayout13 );
- layout17 = new QHBoxLayout( 0, 0, 6, "layout17");
+ tqlayout17 = new TQHBoxLayout( 0, 0, 6, "tqlayout17");
- fontLabel = new QLabel( defaultSourcePrefsFrame, "fontLabel" );
- layout17->addWidget( fontLabel );
+ fontLabel = new TQLabel( defaultSourcePrefsFrame, "fontLabel" );
+ tqlayout17->addWidget( fontLabel );
fontRequester = new KFontRequester( defaultSourcePrefsFrame, "fontRequester" );
- layout17->addWidget( fontRequester );
- defaultSourcePrefsFrameLayout->addLayout( layout17 );
+ tqlayout17->addWidget( fontRequester );
+ defaultSourcePrefsFrameLayout->addLayout( tqlayout17 );
- layout18 = new QHBoxLayout( 0, 0, 6, "layout18");
+ tqlayout18 = new TQHBoxLayout( 0, 0, 6, "tqlayout18");
- alignmentLabel = new QLabel( defaultSourcePrefsFrame, "alignmentLabel" );
- layout18->addWidget( alignmentLabel );
+ tqalignmentLabel = new TQLabel( defaultSourcePrefsFrame, "tqalignmentLabel" );
+ tqlayout18->addWidget( tqalignmentLabel );
- alignmentComboBox = new QComboBox( FALSE, defaultSourcePrefsFrame, "alignmentComboBox" );
- layout18->addWidget( alignmentComboBox );
- spacer2 = new QSpacerItem( 350, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
- layout18->addItem( spacer2 );
- defaultSourcePrefsFrameLayout->addLayout( layout18 );
+ tqalignmentComboBox = new TQComboBox( FALSE, defaultSourcePrefsFrame, "tqalignmentComboBox" );
+ tqlayout18->addWidget( tqalignmentComboBox );
+ spacer2 = new TQSpacerItem( 350, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
+ tqlayout18->addItem( spacer2 );
+ defaultSourcePrefsFrameLayout->addLayout( tqlayout18 );
LabelSourcePrefsLayout->addWidget( defaultSourcePrefsFrame );
languageChange();
- resize( QSize(299, 135).expandedTo(minimumSizeHint()) );
+ resize( TQSize(299, 135).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
@@ -85,7 +85,7 @@ LabelSourcePrefs::LabelSourcePrefs( QWidget* parent, const char* name, WFlags fl
*/
LabelSourcePrefs::~LabelSourcePrefs()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -98,13 +98,13 @@ void LabelSourcePrefs::languageChange()
taskbartitleLabel->setText( tr2i18n( "<br>\n"
"Taskbar visual settings" ) );
colorLabel->setText( tr2i18n( "Foreground color:" ) );
- colorButton->setText( QString::null );
+ colorButton->setText( TQString() );
fontLabel->setText( tr2i18n( "Font:" ) );
- alignmentLabel->setText( tr2i18n( "Alignment:" ) );
- alignmentComboBox->clear();
- alignmentComboBox->insertItem( tr2i18n( "Left" ) );
- alignmentComboBox->insertItem( tr2i18n( "Center" ) );
- alignmentComboBox->insertItem( tr2i18n( "Right" ) );
+ tqalignmentLabel->setText( tr2i18n( "Alignment:" ) );
+ tqalignmentComboBox->clear();
+ tqalignmentComboBox->insertItem( tr2i18n( "Left" ) );
+ tqalignmentComboBox->insertItem( tr2i18n( "Center" ) );
+ tqalignmentComboBox->insertItem( tr2i18n( "Right" ) );
}
#include "labelsourcePrefs.moc"
@@ -11,72 +11,72 @@
/*
- * Constructs a LabelSourcePrefs as a child of 'parent', with the
+ * Constructs a LabelSourcePrefs as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/